diff Core/Compression/ZlibCompressor.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 3959d33612cc
children c996319e90bc
line wrap: on
line diff
--- a/Core/Compression/ZlibCompressor.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/Compression/ZlibCompressor.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,15 +23,15 @@
 #include <stdio.h>
 #include <string.h>
 #include <zlib.h>
-#include "../PalantirException.h"
+#include "../PalanthirException.h"
 
-namespace Palantir
+namespace Palanthir
 {
   void ZlibCompressor::SetCompressionLevel(uint8_t level)
   {
     if (level >= 10)
     {
-      throw PalantirException("Zlib compression level must be between 0 (no compression) and 9 (highest compression");
+      throw PalanthirException("Zlib compression level must be between 0 (no compression) and 9 (highest compression");
     }
   }
 
@@ -70,10 +70,10 @@
       switch (error)
       {
       case Z_MEM_ERROR:
-        throw PalantirException(ErrorCode_NotEnoughMemory);
+        throw PalanthirException(ErrorCode_NotEnoughMemory);
 
       default:
-        throw PalantirException(ErrorCode_InternalError);
+        throw PalanthirException(ErrorCode_InternalError);
       }  
     }
   }
@@ -91,7 +91,7 @@
 
     if (compressedSize < sizeof(size_t))
     {
-      throw PalantirException("Zlib: The compressed buffer is ill-formed");
+      throw PalanthirException("Zlib: The compressed buffer is ill-formed");
     }
 
     size_t uncompressedLength;
@@ -112,13 +112,13 @@
       switch (error)
       {
       case Z_DATA_ERROR:
-        throw PalantirException("Zlib: Corrupted or incomplete compressed buffer");
+        throw PalanthirException("Zlib: Corrupted or incomplete compressed buffer");
 
       case Z_MEM_ERROR:
-        throw PalantirException(ErrorCode_NotEnoughMemory);
+        throw PalanthirException(ErrorCode_NotEnoughMemory);
 
       default:
-        throw PalantirException(ErrorCode_InternalError);
+        throw PalanthirException(ErrorCode_InternalError);
       }  
     }
   }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium